==> HTML-Menu-TreeView-0.6.3.tar.gz: HTML-Menu-TreeView-0.6.3/htdocs/style/Crystal/16/html-menu-treeview/preload.js <==
folderClosed = new Image(16,16);
folderClosed.src='/style/Crystal/16/html-menu-treeview/folderClosed.gif';
plusNodeClosed = new Image(16,16);
plusNodeClosed.src='/style/Crystal/16/html-menu-treeview/plusNodeClosed.gif';
lastPlusNodeClosed = new Image(16,16);
lastPlusNodeClosed.src='/style/Crystal/16/html-menu-treeview/lastPlusNodeClosed.gif';
clasicPlusNodeClosed = new Image(16,16);
clasicPlusNodeClosed.src='/style/Crystal/16/html-menu-treeview/clasicPlusNodeClosed.gif';
clasicLastPlusNodeClosed = new Image(16,16);
clasicLastPlusNodeClosed.src='/style/Crystal/16/html-menu-treeview/clasicLastPlusNodeClosed.gif';
folderManClosed = new Image(16,16);
folderManClosed.src='/style/Crystal/16/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(16,16);
folderGray.src='/style/Crystal/16/html-menu-treeview/folderGray.gif';
folderGreen = new Image(16,16);
folderGreen.src='/style/Crystal/16/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(16,16);
folderViolet.src='/style/Crystal/16/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(16,16);
folderYellowClosed.src='/style/Crystal/16/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(16,16);
folderOrangeClosed.src='/style/Crystal/16/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(16,16);
folderManClosed.src='/style/Crystal/16/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(16,16);
folderHtmlClosed.src='/style/Crystal/16/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(16,16);
folderFavoriteClosed.src='/style/Crystal/16/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(16,16);
folderTextClosed.src='/style/Crystal/16/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(16,16);
folderLockedClosed.src='/style/Crystal/16/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(16,16);
folderCrystalClosed.src='/style/Crystal/16/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(16,16);
folderVideoClosed.src='/style/Crystal/16/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(16,16);
folderPrintClosed.src='/style/Crystal/16/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(16,16);
folderImageClosed.src='/style/Crystal/16/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(16,16);
folderSoundClosed.src='/style/Crystal/16/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(16,16);
folderImportantClosed.src='/style/Crystal/16/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(16,16);
folderTarClosed.src='/style/Crystal/16/html-menu-treeview/folderTarClosed.gif';

==> HTML-Menu-TreeView-0.6.5.tar.gz: HTML-Menu-TreeView-0.6.5/htdocs/style/Crystal/16/html-menu-treeview/preload.js <==
folderClosed = new Image(16,16);
folderClosed.src='/style/Crystal/16/html-menu-treeview/folderClosed.gif';
plusNode = new Image(16,16);
plusNode.src='/style/Crystal/16/html-menu-treeview/plusNode.gif';
lastplusNode = new Image(16,16);
lastplusNode.src='/style/Crystal/16/html-menu-treeview/lastplusNode.gif';
clasicplusNode = new Image(16,16);
clasicplusNode.src='/style/Crystal/16/html-menu-treeview/clasicplusNode.gif';
clasicLastplusNode = new Image(16,16);
clasicLastplusNode.src='/style/Crystal/16/html-menu-treeview/clasicLastplusNode.gif';
folderManClosed = new Image(16,16);
folderManClosed.src='/style/Crystal/16/html-menu-treeview/folderManClosed.gif';
folderGray = new Image(16,16);
folderGray.src='/style/Crystal/16/html-menu-treeview/folderGray.gif';
folderGreen = new Image(16,16);
folderGreen.src='/style/Crystal/16/html-menu-treeview/folderGreen.gif';
folderViolet = new Image(16,16);
folderViolet.src='/style/Crystal/16/html-menu-treeview/folderViolet.gif';
folderYellowClosed = new Image(16,16);
folderYellowClosed.src='/style/Crystal/16/html-menu-treeview/folderYellowClosed.gif';
folderOrangeClosed = new Image(16,16);
folderOrangeClosed.src='/style/Crystal/16/html-menu-treeview/folderOrangeClosed.gif';
folderManClosed = new Image(16,16);
folderManClosed.src='/style/Crystal/16/html-menu-treeview/folderManClosed.gif';
folderHtmlClosed = new Image(16,16);
folderHtmlClosed.src='/style/Crystal/16/html-menu-treeview/folderHtmlClosed.gif';
folderFavoriteClosed = new Image(16,16);
folderFavoriteClosed.src='/style/Crystal/16/html-menu-treeview/folderFavoriteClosed.gif';
folderTextClosed = new Image(16,16);
folderTextClosed.src='/style/Crystal/16/html-menu-treeview/folderTextClosed.gif';
folderLockedClosed = new Image(16,16);
folderLockedClosed.src='/style/Crystal/16/html-menu-treeview/folderLockedClosed.gif';
folderCrystalClosed = new Image(16,16);
folderCrystalClosed.src='/style/Crystal/16/html-menu-treeview/folderCrystalClosed.gif';
folderVideoClosed = new Image(16,16);
folderVideoClosed.src='/style/Crystal/16/html-menu-treeview/folderVideoClosed.gif';
folderPrintClosed = new Image(16,16);
folderPrintClosed.src='/style/Crystal/16/html-menu-treeview/folderPrintClosed.gif';
folderImageClosed = new Image(16,16);
folderImageClosed.src='/style/Crystal/16/html-menu-treeview/folderImageClosed.gif';
folderSoundClosed = new Image(16,16);
folderSoundClosed.src='/style/Crystal/16/html-menu-treeview/folderSoundClosed.gif';
folderImportantClosed = new Image(16,16);
folderImportantClosed.src='/style/Crystal/16/html-menu-treeview/folderImportantClosed.gif';
folderTarClosed = new Image(16,16);
folderTarClosed.src='/style/Crystal/16/html-menu-treeview/folderTarClosed.gif';
